@@ -34,7 +34,7 @@ def slugify(value, allow_unicode=False):
 
 
 class delhi_hc_search:
-    def __init__(self, case_type, case_year, case_no=None, headless=True, no_image=True, delay=1, ret=False):
+    def __init__(self, case_type, case_year, case_no=None, enable_download = False, scan_limit = 5, delay=1, ret=False, headless=True, no_image=True):
         """
         The Delhi High court website provides three ways to look for case data:
         1. Using Case type
@@ -82,6 +82,8 @@ class delhi_hc_search:
         self.delay = delay
         self.ret = ret
         self.order_subpage_data = []
+        self.enable_download = enable_download
+        self.scan_limit = scan_limit
 
         # Assertions
         if self.case_no:
@@ -166,8 +168,9 @@ class delhi_hc_search:
         self.valid_links = remove_none(list(set(self.page_not_visited) - set(self.page_visited)))
         page_counter = 0
         data = []
-        while self.valid_links:
-            print(f'No. of pages_visited: {page_counter}', end='\r')
+
+        while self.valid_links and (page_counter <= self.scan_limit):
+            print(f'No. of pages_visited: {page_counter}', flush=True)
             self.driver.get(self.valid_links[0])
             self.page_visited.append(self.valid_links[0])
             current_page = self.driver.page_source
@@ -219,7 +222,8 @@ class delhi_hc_search:
                     for order in order_links:
                         pdf_links.append(order)
 
-                    self.download_pdfs(pdf_links, order_prefix, oj_window, main_window)
+                    if self.enable_download:
+                        self.download_pdfs(pdf_links, order_prefix, oj_window, main_window)
 
                     self.driver.close()
                     self.driver.switch_to.window(main_window)
@@ -301,7 +305,7 @@ class delhi_hc_search:
                 case_status_data[f'n_{i}']['case_status2'] = case_status2
                 case_status_data[f'n_{i}']['judgement_date'] = judgement_date
             return case_status_data
-        except:
+        except IndexError:
             return None
 
     def get_order_page_links(self, html):
@@ -322,30 +326,30 @@ class delhi_hc_search:
         orders = {}
         try:
             for i in range(len(li)):
-            """
-            The Delhi High court website essentially has a a case status page and a button
-            which gives details of all the orders related to that case. This function
-            parses the page to provide structured data from the page. Variables include
-            serial no, date of order, corrigendum text
+                """
+                The Delhi High court website essentially has a a case status page and a button
+                which gives details of all the orders related to that case. This function
+                parses the page to provide structured data from the page. Variables include
+                serial no, date of order, corrigendum text
+    
+                """
+                s0 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[0].get_text())
+                sr_no = s0.replace(".", "")
 
-            """
-            s0 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[0].get_text())
-            sr_no = s0.replace(".", "")
+                s1 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[1].get_text())
+                case_no = s1
 
-            s1 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[1].get_text())
-            case_no = s1
+                s2 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[2].get_text())
+                date_of_order = s2
 
-            s2 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[2].get_text())
-            date_of_order = s2
+                s3 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[3].get_text())
+                corrigendum = s3
 
-            s3 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[3].get_text())
-            corrigendum = s3
-
-            orders[f'n_{i + 1}'] = {}
-            orders[f'n_{i + 1}']['sr_no'] = sr_no
-            orders[f'n_{i + 1}']['case_no'] = case_no
-            orders[f'n_{i + 1}']['date_of_order'] = date_of_order
-            orders[f'n_{i + 1}']['corrigendum'] = corrigendum
+                orders[f'n_{i + 1}'] = {}
+                orders[f'n_{i + 1}']['sr_no'] = sr_no
+                orders[f'n_{i + 1}']['case_no'] = case_no
+                orders[f'n_{i + 1}']['date_of_order'] = date_of_order
+                orders[f'n_{i + 1}']['corrigendum'] = corrigendum
             return orders
 
         except:
